import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class RouterTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouterTransitions(
      {@required this.context,
      @required this.child,
      this.replacement = false,
      this.duration = const Duration(milliseconds: 300),
      this.animation = AnimationType.normal}) {
    switch (this.animation) {
      case AnimationType.normal:
        // TODO: Handle this case.
        this._normalTransition();
        break;
      case AnimationType.fadeIn:
        // TODO: Handle this case.
        this._fadeInTransition();
        break;
    }
    //Navigator.push(this.context,MaterialPageRoute(builder: (BuildContext context) => this.child));
  }

  void _pushPage(Route route) => Navigator.push(context, route);

  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  void _normalTransition() {
    final route =
        MaterialPageRoute(builder: (BuildContext context) => this.child);

    (this.replacement)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (BuildContext context, Animation<double> animation,
            Animation<double> secondaryAnimation) {
          return this.child;
        },
        transitionDuration: this.duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            child: child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });

    if (this.replacement) {
      this._pushReplacementPage(route);
    } else {
      this._pushPage(route);
    }
  }
}
